﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Input;

namespace XNA_Demo
{
    public class Player : GameObject
    {
        private float moveScale = 180f;
        private bool dead = false;

        public bool Dead
        {
            get { return dead; }
        }

        #region Constructor
        public Player(ContentManager content)
        {
            // hero texture provided by: Reiner “Tiles” Prokein - http://www.reinerstilesets.de/
            Texture2D hero = content.Load<Texture2D>(@"Textures\Sprites\Player\hero_sword_walk48");
            Texture2D idle = content.Load<Texture2D>(@"Textures\Sprites\Player\idle");
            animations.Add("up",
                new AnimationStrip(hero, 48, 48, 0, "up"));
            animations["up"].LoopAnimation = true;
            animations.Add("upRight",
                new AnimationStrip(hero, 48, 48, 1, "upRight"));
            animations["upRight"].LoopAnimation = true;
            animations.Add("right",
                new AnimationStrip(hero, 48, 48, 2, "right"));
            animations["right"].LoopAnimation = true;
            animations.Add("downRight",
                new AnimationStrip(hero, 48, 48, 3, "downRight"));
            animations["downRight"].LoopAnimation = true;
            animations.Add("down",
                new AnimationStrip(hero, 48, 48, 4, "down"));
            animations["down"].LoopAnimation = true;
            animations.Add("downLeft",
                new AnimationStrip(hero, 48, 48, 5, "downLeft"));
            animations["downLeft"].LoopAnimation = true;
            animations.Add("left",
                new AnimationStrip(hero, 48, 48, 6, "left"));
            animations["left"].LoopAnimation = true;
            animations.Add("upLeft",
                new AnimationStrip(hero, 48, 48, 7, "upLeft"));
            animations["upLeft"].LoopAnimation = true;

            animations.Add("idle",
                new AnimationStrip(idle, 48, "idle"));
            animations["idle"].LoopAnimation = false;

            frameWidth = 48;
            frameHeight = 48;
            CollisionRectangle = new Rectangle(15, 6, 16, 28);

            drawDepth = 0.825f;

            enabled = true;
            codeBasedBlocks = false;
            PlayAnimation("idle");
        }
        #endregion

        #region Public Methods
        public override void Update(GameTime gameTime)
        {
            if (!Dead)
            {
                string newAnimation = "idle";
                velocity = new Vector2(0, 0);
                GamePadState gamePad = GamePad.GetState(PlayerIndex.One);
                KeyboardState keyState = Keyboard.GetState();

                if (keyState.IsKeyDown(Keys.Left) ||
                    (gamePad.ThumbSticks.Left.X < -0.3f))
                {
                    newAnimation = "left";
                    velocity = new Vector2(-moveScale, velocity.Y);
                }
                if (keyState.IsKeyDown(Keys.Right) ||
                    (gamePad.ThumbSticks.Left.X > 0.3f))
                {
                    newAnimation = "right";
                    velocity = new Vector2(moveScale, velocity.Y);
                }
                if (keyState.IsKeyDown(Keys.Up) ||
                    (gamePad.ThumbSticks.Left.Y > 0.3f))
                {
                    newAnimation = "up";
                    velocity = new Vector2(velocity.X, -moveScale);
                }
                if (keyState.IsKeyDown(Keys.Down) ||
                    (gamePad.ThumbSticks.Left.Y < -0.3f))
                {
                    newAnimation = "down";
                    velocity = new Vector2(velocity.X, moveScale);
                }

                // diagonal moves, just update the animation
                if ((keyState.IsKeyDown(Keys.Up) ||
                    (gamePad.ThumbSticks.Left.Y > 0.3f)) &&
                    (keyState.IsKeyDown(Keys.Right) ||
                    (gamePad.ThumbSticks.Left.X > 0.3f)))
                {
                    newAnimation = "upRight";
                }
                if ((keyState.IsKeyDown(Keys.Up) ||
                    (gamePad.ThumbSticks.Left.Y > 0.3f)) &&
                    (keyState.IsKeyDown(Keys.Left) ||
                    (gamePad.ThumbSticks.Left.X < -0.3f)))
                {
                    newAnimation = "upLeft";
                }
                if ((keyState.IsKeyDown(Keys.Down) ||
                    (gamePad.ThumbSticks.Left.Y < -0.3f)) &&
                    (keyState.IsKeyDown(Keys.Right) ||
                    (gamePad.ThumbSticks.Left.X > 0.3f)))
                {
                    newAnimation = "downRight";
                }
                if ((keyState.IsKeyDown(Keys.Down) ||
                    (gamePad.ThumbSticks.Left.Y < -0.3f)) &&
                    (keyState.IsKeyDown(Keys.Left) ||
                    (gamePad.ThumbSticks.Left.X < -0.3f)))
                {
                    newAnimation = "downLeft";
                }

                if (newAnimation != currentAnimation)
                {
                    PlayAnimation(newAnimation);
                }
            }
            base.Update(gameTime);
        }
        #endregion
    }
}





